@@ -26,6 +26,15 @@ function test_bluer_algo_help() {
         "@algo image_classifier model prediction_test" \
         "@algo image_classifier model train" \
         \
+        "@algo yolo" \
+        "@algo yolo dataset" \
+        "@algo yolo dataset ingest" \
+        \
+        "@algo socket" \
+        "@algo socket test" \
+        \
+        "@algo tracker" \
+        \
         "@image_classifier" \
         "@image_classifier dataset" \
         "@image_classifier dataset ingest" \
@@ -35,7 +44,12 @@ function test_bluer_algo_help() {
         "@image_classifier model prediction_test" \
         "@image_classifier model train" \
         \
-        "@algo tracker" \
+        "@yolo" \
+        "@yolo dataset" \
+        "@yolo dataset ingest" \
+        "@yolo dataset review" \
+        "@yolo model" \
+        "@yolo model train" \
         \
         "bluer_algo"; do
         bluer_ai_eval ,$options \
