@@ -10,6 +10,7 @@ class MeanShiftTracker(GenericTracker):
         self,
         frame: np.ndarray,
         track_window: Tuple[int, int, int, int],
+        log: bool = False,
     ) -> Tuple[
         Any,
         Tuple[int, int, int, int],
@@ -21,9 +22,26 @@ class MeanShiftTracker(GenericTracker):
         # apply meanshift to get the new location
         ret, track_window = cv2.meanShift(dst, track_window, self.term_crit)
 
-        # Draw it on image
         x, y, w, h = track_window
+        self.history.append(
+            (
+                x + w // 2,
+                y + h // 2,
+            )
+        )
 
-        output_image = cv2.rectangle(frame, (x, y), (x + w, y + h), 255, 2)
+        # Draw it on image
+        output_image = np.array([])
+        if self.with_gui or log:
+            output_image = cv2.rectangle(frame, (x, y), (x + w, y + h), 255, 2)
+
+            for i in range(len(self.history) - 1):
+                cv2.line(
+                    output_image,
+                    self.history[i],
+                    self.history[i + 1],
+                    color=(0, 255, 0),
+                    thickness=2,
+                )
 
         return ret, track_window, output_image
